'use strict';

const ts = require('typescript');

const _interopDefault = e => e && e.__esModule ? e : { default: e };

const ts__default = /*#__PURE__*/_interopDefault(ts);

const index = (compilerOptions) => {
    compilerOptions = {
        ...compilerOptions,
        jsx: ts__default.default.JsxEmit.Preserve,
        jsxImportSource: "react",
        module: ts__default.default.ModuleKind.ESNext,
        moduleResolution: ts__default.default.ModuleResolutionKind.NodeJs,
        sourceMap: true,
        inlineSourceMap: false,
        inlineSources: true,
        allowJs: true,
        importHelpers: true,
        strict: true,
        esModuleInterop: true,
        skipLibCheck: true,
        forceConsistentCasingInFileNames: true,
    };
    const formatDiagnosticsHost = {
        getCurrentDirectory: ts__default.default.sys.getCurrentDirectory,
        getCanonicalFileName: (fileName) => fileName,
        getNewLine: () => ts__default.default.sys.newLine,
    };
    return {
        name: "typescript-transpile-module",
        transform(code, id) {
            const { diagnostics, outputText, sourceMapText } = ts__default.default.transpileModule(code, {
                compilerOptions,
                fileName: id,
                reportDiagnostics: true,
            });
            if (diagnostics?.length) {
                const message = ts__default.default.formatDiagnosticsWithColorAndContext(diagnostics, formatDiagnosticsHost);
                this.warn(message);
            }
            return { code: outputText, map: sourceMapText };
        },
    };
};

module.exports = index;
//# sourceMappingURL=index.cjs.map
